@@ -89,9 +89,12 @@ class MainApp(App):
         return layout
 
     def morpionLaunch(self, instance):
+        App.get_running_app().stop()
+        Window.close()
         os.system('bash -c "python3 -m Morpion"')
 
 
+
     def logoPress(self, instance):
         if self.number == 1:
             self.label.text = "Bien joué, je suis démasqué !"
